@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: adjusted_unknowns.h,v 1.2 2007/06/26 15:04:07 cepek Exp $
+ *  $Id: adjusted_unknowns.h,v 1.3 2008/04/13 10:02:31 cepek Exp $
  */
 
 #ifndef GaMa_GaMaProg_Vyrovnane_Nezname_h_
@@ -38,7 +38,7 @@ void AdjustedUnknowns(GaMaLib::LocalNetwork* IS, OutStream& out)
   using namespace std;
   using namespace GaMaLib;
 
-  const int y_sign = Consistent(IS->PD) ? +1 : -1;
+  const int y_sign = GaMaConsistent(IS->PD) ? +1 : -1;
   
   const Vec& x = IS->solve();
   Double kki = IS->conf_int_coef();
