@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: adj.cpp,v 1.6 2007/06/26 15:04:09 cepek Exp $
+ *  $Id: adj.cpp,v 1.8 2007/12/22 20:54:53 cepek Exp $
  */
 
 #include <gnu_gama/adj/adj.h>
@@ -426,7 +426,7 @@ const Vec<>& Adj::r()
 
 
 
-double Adj::q_bb(Index i, Index j)
+double Adj::q_bb(Index i, Index j) 
 {
   double* ib;
   double* ie;
@@ -443,7 +443,7 @@ double Adj::q_bb(Index i, Index j)
       ie = data->A->end(i);
       in = data->A->ibegin(i);
       t  = 0;
-      while (ib != ie)  t += *ib++ * q_xx(*in++, *jn);
+      while (ib != ie)  t += *ib++ * least_squares->q0_xx(*in++, *jn);
 
       sum += *jb * t;
       jb++;
