@@ -1,5 +1,5 @@
 /*  
-    C++ Matrix/Vector templates (GNU Gama / matvec 1.0.00)
+    C++ Matrix/Vector templates (GNU Gama / matvec 1.0.01)
     Copyright (C) 2002, 2005, 2007  Ales Cepek <cepek@gnu.org>
 
     This file is part of the GNU Gama C++ Matrix/Vector template library.
@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: covmat.h,v 1.4 2007/12/01 20:21:18 cepek Exp $
+ *  $Id: covmat.h,v 1.5 2008/10/28 12:39:18 cepek Exp $
  *  http://www.gnu.org/software/gama/
  */
 
@@ -46,7 +46,7 @@
  */
 
 
-namespace GNU_gama {
+namespace GNU_gama {   /** \brief Covariance Matrix (symmetric band matrix) */
 
 
   template <typename Float=double, typename Exc=Exception::matvec>
